@@ -1,19 +1,21 @@
-from datetime import datetime
-from enum import Enum
+import datetime
+import enum
 from typing import Any, Dict, List, Optional, Union
 
-from devtools import pformat
+import devtools
 import httpx
-from pydantic import BaseModel, Field, parse_obj_as, validator
+import pydantic
 
-from servo.types import Adjustment, Control, Duration, Numeric
+import servo.types
 
 USER_AGENT = "github.com/opsani/servox"
 
+
 class UnexpectedEventError(RuntimeError):
     pass
 
-class Command(str, Enum):
+
+class Command(str, enum.Enum):
     DESCRIBE = "DESCRIBE"
     MEASURE = "MEASURE"
     ADJUST = "ADJUST"
@@ -31,7 +33,7 @@ class Command(str, Enum):
             return None
 
 
-class Event(str, Enum):
+class Event(str, enum.Enum):
     HELLO = "HELLO"
     GOODBYE = "GOODBYE"
     DESCRIPTION = "DESCRIPTION"
@@ -40,8 +42,8 @@ class Event(str, Enum):
     MEASUREMENT = "MEASUREMENT"
 
 
-class Request(BaseModel):
-    event: Union[Event, str] # TODO: Needs to be rethought -- used adhoc in some cases
+class Request(pydantic.BaseModel):
+    event: Union[Event, str]  # TODO: Needs to be rethought -- used adhoc in some cases
     param: Optional[Dict[str, Any]]  # TODO: Switch to a union of supported types
 
     class Config:
@@ -50,25 +52,27 @@ class Request(BaseModel):
         }
 
 
-class Status(BaseModel):
+class Status(pydantic.BaseModel):
     status: str
     message: Optional[str]
     reason: Optional[str]
 
-UNEXPECTED_EVENT = 'unexpected-event'
 
-class SleepResponse(BaseModel):
+UNEXPECTED_EVENT = "unexpected-event"
+
+
+class SleepResponse(pydantic.BaseModel):
     pass
 
 
 # SleepResponse '{"cmd": "SLEEP", "param": {"duration": 60, "data": {"reason": "no active optimization pipeline"}}}'
 
 # Instructions from servo on what to measure
-class MeasureParams(BaseModel):
+class MeasureParams(pydantic.BaseModel):
     metrics: List[str]
-    control: Control
+    control: servo.types.Control
 
-    @validator('metrics', always=True, pre=True)
+    @pydantic.validator("metrics", always=True, pre=True)
     @classmethod
     def coerce_metrics(cls, value) -> List[str]:
         if isinstance(value, dict):
@@ -76,8 +80,9 @@ class MeasureParams(BaseModel):
 
         return value
 
-class CommandResponse(BaseModel):
-    command: Command = Field(alias="cmd",)
+
+class CommandResponse(pydantic.BaseModel):
+    command: Command = pydantic.Field(alias="cmd")
     param: Optional[
         Union[MeasureParams, Dict[str, Any]]
     ]  # TODO: Switch to a union of supported types
@@ -88,7 +93,7 @@ class CommandResponse(BaseModel):
         }
 
 
-class StatusMessage(BaseModel):
+class StatusMessage(pydantic.BaseModel):
     status: str
     message: Optional[str]
 
@@ -97,7 +102,9 @@ class Mixin:
     @property
     def api_headers(self) -> Dict[str, str]:
         if not self.optimizer:
-            raise RuntimeError(f"cannot construct API headers: optimizer is not configured")
+            raise RuntimeError(
+                f"cannot construct API headers: optimizer is not configured"
+            )
         return {
             "Authorization": f"Bearer {self.optimizer.token}",
             "User-Agent": USER_AGENT,
@@ -111,14 +118,18 @@ class Mixin:
     def api_client(self, **kwargs) -> httpx.AsyncClient:
         """Yields an httpx.Client instance configured to talk to Opsani API"""
         if not self.optimizer:
-            raise RuntimeError(f"cannot construct API client: optimizer is not configured")
-        return httpx.AsyncClient(**{ **self.api_client_options, **kwargs })
+            raise RuntimeError(
+                f"cannot construct API client: optimizer is not configured"
+            )
+        return httpx.AsyncClient(**{**self.api_client_options, **kwargs})
 
     def api_client_sync(self, **kwargs) -> httpx.Client:
         """Yields an httpx.Client instance configured to talk to Opsani API"""
         if not self.optimizer:
-            raise RuntimeError(f"cannot construct API client: optimizer is not configured")
-        return httpx.Client(**{ **self.api_client_options, **kwargs })
+            raise RuntimeError(
+                f"cannot construct API client: optimizer is not configured"
+            )
+        return httpx.Client(**{**self.api_client_options, **kwargs})
 
     async def report_progress(self, **kwargs):
         request = self.progress_request(**kwargs)
@@ -128,77 +139,91 @@ class Mixin:
             # We have lost sync with the backend, raise an exception to halt broken execution
             raise UnexpectedEventError(status.reason)
 
-    def progress_request(self,
+    def progress_request(
+        self,
         operation: str,
-        progress: Numeric,
+        progress: servo.types.Numeric,
         started_at: datetime,
         message: Optional[str],
         *,
         connector: Optional[str] = None,
-        event_context: Optional['EventContext'] = None,
-        time_remaining: Optional[Union[Numeric, Duration]] = None,
+        event_context: Optional["servo.events.EventContext"] = None,
+        time_remaining: Optional[
+            Union[servo.types.Numeric, servo.types.Duration]
+        ] = None,
         logs: Optional[List[str]] = None,
     ) -> None:
         def set_if(d: Dict, k: str, v: Any):
-            if v is not None: d[k] = v
+            if v is not None:
+                d[k] = v
 
         # Normalize progress to positive percentage
         if progress < 1.0:
             progress = progress * 100
 
         # Calculate runtime
-        runtime = Duration(datetime.now() - started_at)
+        runtime = servo.types.Duration(datetime.datetime.now() - started_at)
 
         # Produce human readable and remaining time in seconds values (if given)
         if time_remaining:
             if isinstance(time_remaining, (int, float)):
                 time_remaining_in_seconds = time_remaining
-                time_remaining = Duration(time_remaining_in_seconds)
-            elif isinstance(time_remaining, timedelta):
+                time_remaining = servo.types.Duration(time_remaining_in_seconds)
+            elif isinstance(time_remaining, datetime.timedelta):
                 time_remaining_in_seconds = time_remaining.total_seconds()
             else:
-                raise ValueError(f"Unknown value of type '{time_remaining.__class__.__name__}' for parameter 'time_remaining'")
+                raise ValueError(
+                    f"Unknown value of type '{time_remaining.__class__.__name__}' for parameter 'time_remaining'"
+                )
         else:
             time_remaining_in_seconds = None
 
+        # FIXME: Tied off until reconciled with new oco-e enforcement (see https://github.com/opsani/oco/blob/wfc-devel/transport/protocol.py#L62)
         params = dict(
-            connector=self.name,
-            operation=operation,
-            progress=progress,
-            runtime=str(runtime),
-            runtime_in_seconds=runtime.total_seconds()
+            # connector=self.name,
+            # operation=operation,
+            progress=float(progress),
+            runtime=float(runtime.total_seconds()),
+            # runtime=str(runtime),
+            # runtime_in_seconds=runtime.total_seconds(),
         )
-        set_if(params, 'connector', connector)
-        set_if(params, 'event', str(event_context))
-        set_if(params, 'time_remaining', str(time_remaining) if time_remaining else None)
-        set_if(params, 'time_remaining_in_seconds', str(time_remaining_in_seconds) if time_remaining_in_seconds else None)
-        set_if(params, 'message', message)
-        set_if(params, 'logs', logs)
+        # set_if(params, "connector", connector)
+        # set_if(params, "event", str(event_context))
+        # set_if(
+        #     params, "time_remaining", str(time_remaining) if time_remaining else None
+        # )
+        # set_if(
+        #     params,
+        #     "time_remaining_in_seconds",
+        #     str(time_remaining_in_seconds) if time_remaining_in_seconds else None,
+        # )
+        set_if(params, "message", message)
+        # set_if(params, "logs", logs)
 
         return (operation, params)
 
-
     # NOTE: Opsani API primitive
     # @backoff.on_exception(backoff.expo, (httpx.HTTPError), max_time=180, max_tries=12)
-    async def _post_event(self, event: Event, param) -> Union[CommandResponse, Status]:        
+    async def _post_event(self, event: Event, param) -> Union[CommandResponse, Status]:
         async with self.api_client() as client:
             event_request = Request(event=event, param=param)
-            self.logger.trace(f"POST event request: {pformat(event_request)}")
+            self.logger.trace(f"POST event request: {devtools.pformat(event_request)}")
 
             try:
                 response = await client.post("servo", data=event_request.json())
                 response.raise_for_status()
                 response_json = response.json()
-                self.logger.trace(f"POST event response ({response.status_code} {response.reason_phrase}): {pformat(response_json)}")
-
-                return parse_obj_as(Union[CommandResponse, Status], response_json)
-            except httpx.HTTPError:
-                self.logger.error(
-                    f"HTTP error encountered while posting {event} event"
+                self.logger.trace(
+                    f"POST event response ({response.status_code} {response.reason_phrase}): {devtools.pformat(response_json)}"
                 )
-                self.logger.trace(pformat(event_request))
-                raise
 
+                return pydantic.parse_obj_as(
+                    Union[CommandResponse, Status], response_json
+                )
+            except httpx.HTTPError:
+                self.logger.error(f"HTTP error encountered while posting {event} event")
+                self.logger.trace(devtools.pformat(event_request))
+                raise
 
     def _post_event_sync(self, event: Event, param) -> Union[CommandResponse, Status]:
         event_request = Request(event=event, param=param)
@@ -210,19 +235,20 @@ class Mixin:
                 self.logger.error(
                     f"HTTP error encountered while posting {event.value} event"
                 )
-                self.logger.trace(pformat(event_request))
+                self.logger.trace(devtools.pformat(event_request))
                 raise
 
-        return parse_obj_as(Union[CommandResponse, Status], response.json())
+        return pydantic.parse_obj_as(Union[CommandResponse, Status], response.json())
 
-def descriptor_to_adjustments(descriptor: dict) -> List[Adjustment]:
+
+def descriptor_to_adjustments(descriptor: dict) -> List[servo.types.Adjustment]:
     adjustments = []
     for component_name, component in descriptor["application"]["components"].items():
         for setting_name, attrs in component["settings"].items():
-            adjustment = Adjustment(
+            adjustment = servo.types.Adjustment(
                 component_name=component_name,
                 setting_name=setting_name,
-                value=attrs["value"]
+                value=attrs["value"],
             )
             adjustments.append(adjustment)
     return adjustments
