@@ -6,22 +6,24 @@
 # reinstalls of all package dependencies.
 # Do not implement meaningful functionality here. Instead import and
 # dispatch the intent into focused modules to do the real work.
-from dotenv import find_dotenv, load_dotenv
+import dotenv
 
-from servo.cli import ServoCLI
-from servo.connector import ConnectorLoader
-from servo.logging import logger
+import servo
+import servo.cli
 
-def run_cli():
-    load_dotenv(find_dotenv(usecwd=True))
+
+def run_cli() -> None:
+    dotenv.load_dotenv(dotenv.find_dotenv(usecwd=True))
 
     # NOTE: We load connectors here because waiting until assembly
     # is too late for registering CLI commands
     try:
-        for connector in ConnectorLoader().load():
-            logger.debug(f"Loaded {connector.__qualname__}")
+        for connector in servo.connector.ConnectorLoader().load():
+            servo.logger.debug(f"Loaded {connector.__qualname__}")
     except Exception:
-        logger.exception("failed loading connectors via discovery", backtrace=True, diagnose=True)
+        servo.logger.exception(
+            "failed loading connectors via discovery", backtrace=True, diagnose=True
+        )
 
-    cli = ServoCLI()
+    cli = servo.cli.ServoCLI()
     cli()
